==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_entities/lot_001/Lot.java <==

package net.datastream.schemas.mp_entities.lot_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.LOTID_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXPIRATIONDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTLOT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "lotid",
    "classid",
    "expirationdate",
    "manufactlot",
    "userdefinedarea"
})
@XmlRootElement(name = "Lot")
public class Lot {

    @XmlElement(name = "LOTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected LOTID_Type lotid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "EXPIRATIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME expirationdate;
    @XmlElement(name = "MANUFACTLOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufactlot;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the lotid property.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Sets the value of the lotid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the expirationdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getEXPIRATIONDATE() {
        return expirationdate;
    }

    /**
     * Sets the value of the expirationdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setEXPIRATIONDATE(DATETIME value) {
        this.expirationdate = value;
    }

    /**
     * Gets the value of the manufactlot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTLOT() {
        return manufactlot;
    }

    /**
     * Sets the value of the manufactlot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTLOT(String value) {
        this.manufactlot = value;
    }

    /**
     * Gets the value of the userdefinedarea property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Sets the value of the userdefinedarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_entities/lot_001/Lot.java <==

package net.datastream.schemas.mp_entities.lot_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.LOTID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXPIRATIONDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTLOT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "lotid",
    "classid",
    "expirationdate",
    "manufactlot",
    "userdefinedarea",
    "standardUserDefinedFields"
})
@XmlRootElement(name = "Lot")
public class Lot {

    @XmlElement(name = "LOTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected LOTID_Type lotid;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "EXPIRATIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME expirationdate;
    @XmlElement(name = "MANUFACTLOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufactlot;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the lotid property.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Sets the value of the lotid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the expirationdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getEXPIRATIONDATE() {
        return expirationdate;
    }

    /**
     * Sets the value of the expirationdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setEXPIRATIONDATE(DATETIME value) {
        this.expirationdate = value;
    }

    /**
     * Gets the value of the manufactlot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTLOT() {
        return manufactlot;
    }

    /**
     * Sets the value of the manufactlot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTLOT(String value) {
        this.manufactlot = value;
    }

    /**
     * Gets the value of the userdefinedarea property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Sets the value of the userdefinedarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
